@@ -21,7 +21,7 @@ pub fn all_matched_lines_filled(
 ) -> Vec<(Option<LineNumber>, Option<LineNumber>)> {
     let matched_lines = all_matched_lines(lhs_mps, rhs_mps);
 
-    compact_gaps(ensure_contiguous(&matched_lines))
+    compact_gaps(&ensure_contiguous(&matched_lines))
 }
 
 fn all_matched_lines(
@@ -37,10 +37,12 @@ fn novel_lines(mps: &[MatchedPos]) -> Vec<LineNumber> {
     let mut lines = HashSet::new();
     for mp in mps {
         match mp.kind {
-            MatchKind::Novel { .. } | MatchKind::ChangedCommentPart {} => {
+            MatchKind::Novel { .. }
+            | MatchKind::NovelWord { .. }
+            | MatchKind::NovelLinePart { .. } => {
                 lines.insert(mp.pos.line);
             }
-            MatchKind::Unchanged { .. } | MatchKind::UnchangedCommentPart { .. } => {}
+            MatchKind::UnchangedToken { .. } => {}
         }
     }
 
@@ -56,8 +58,8 @@ fn matched_lines(mps: &[MatchedPos]) -> Vec<(Option<LineNumber>, Option<LineNumb
     let mut res: Vec<(Option<LineNumber>, Option<LineNumber>)> = vec![];
     for mp in mps {
         let opposite_line = match &mp.kind {
-            MatchKind::Unchanged { opposite_pos, .. }
-            | MatchKind::UnchangedCommentPart { opposite_pos, .. } => {
+            MatchKind::UnchangedToken { opposite_pos, .. }
+            | MatchKind::NovelLinePart { opposite_pos, .. } => {
                 if let Some(highest_opposite_side) = highest_opposite_line {
                     opposite_pos
                         .iter()
@@ -67,7 +69,7 @@ fn matched_lines(mps: &[MatchedPos]) -> Vec<(Option<LineNumber>, Option<LineNumb
                     opposite_pos.first().map(|p| p.line)
                 }
             }
-            MatchKind::Novel { .. } | MatchKind::ChangedCommentPart {} => None,
+            MatchKind::Novel { .. } | MatchKind::NovelWord { .. } => None,
         };
 
         let should_insert = match highest_line {
@@ -125,7 +127,7 @@ pub fn opposite_positions(mps: &[MatchedPos]) -> HashMap<LineNumber, HashSet<Lin
 
     for mp in mps {
         match &mp.kind {
-            MatchKind::Unchanged {
+            MatchKind::UnchangedToken {
                 self_pos,
                 opposite_pos,
                 ..
@@ -135,16 +137,17 @@ pub fn opposite_positions(mps: &[MatchedPos]) -> HashMap<LineNumber, HashSet<Lin
                     opposite_lines.insert(opposite_span.line);
                 }
             }
-            MatchKind::UnchangedCommentPart {
+            MatchKind::NovelLinePart {
                 opposite_pos,
                 self_pos,
+                ..
             } => {
                 let opposite_lines = res.entry(self_pos.line).or_insert_with(HashSet::new);
                 for opposite_span in opposite_pos {
                     opposite_lines.insert(opposite_span.line);
                 }
             }
-            MatchKind::Novel { .. } | MatchKind::ChangedCommentPart { .. } => {}
+            MatchKind::Novel { .. } | MatchKind::NovelWord { .. } => {}
         }
     }
 
@@ -439,7 +442,7 @@ mod tests {
                 },
             },
             MatchedPos {
-                kind: MatchKind::Unchanged {
+                kind: MatchKind::UnchangedToken {
                     highlight: TokenKind::Delimiter,
                     self_pos: vec![matched_pos],
                     opposite_pos: vec![matched_pos],
@@ -454,6 +457,64 @@ mod tests {
         );
     }
 
+    #[test]
+    fn test_novel_lines() {
+        let mps = [
+            MatchedPos {
+                kind: MatchKind::NovelLinePart {
+                    highlight: TokenKind::Delimiter,
+                    self_pos: SingleLineSpan {
+                        line: 0.into(),
+                        start_col: 2,
+                        end_col: 3,
+                    },
+                    opposite_pos: vec![SingleLineSpan {
+                        line: 0.into(),
+                        start_col: 2,
+                        end_col: 3,
+                    }],
+                },
+                pos: SingleLineSpan {
+                    line: 0.into(),
+                    start_col: 2,
+                    end_col: 3,
+                },
+            },
+            MatchedPos {
+                kind: MatchKind::UnchangedToken {
+                    highlight: TokenKind::Delimiter,
+                    self_pos: vec![SingleLineSpan {
+                        line: 1.into(),
+                        start_col: 2,
+                        end_col: 3,
+                    }],
+                    opposite_pos: vec![SingleLineSpan {
+                        line: 1.into(),
+                        start_col: 2,
+                        end_col: 3,
+                    }],
+                },
+                pos: SingleLineSpan {
+                    line: 1.into(),
+                    start_col: 2,
+                    end_col: 3,
+                },
+            },
+            MatchedPos {
+                kind: MatchKind::Novel {
+                    highlight: TokenKind::Delimiter,
+                },
+                pos: SingleLineSpan {
+                    line: 2.into(),
+                    start_col: 1,
+                    end_col: 2,
+                },
+            },
+        ];
+
+        assert_eq!(novel_lines(&mps), vec![0.into(), 2.into()]);
+    }
+
     #[test]
     fn test_merge_in_opposite_lines() {
         let matched_lines = [(Some(1.into()), Some(1.into()))];
