@@ -574,7 +574,7 @@ pub fn ensure_contiguous(
 ///
 /// The returned vec will contain no (None, None) pairs.
 pub fn compact_gaps(
-    items: Vec<(Option<LineNumber>, Option<LineNumber>)>,
+    items: &[(Option<LineNumber>, Option<LineNumber>)],
 ) -> Vec<(Option<LineNumber>, Option<LineNumber>)> {
     let mut res: Vec<(Option<LineNumber>, Option<LineNumber>)> = vec![];
     // A vec of the most recent single-sided lines, e.g.
@@ -583,47 +583,43 @@ pub fn compact_gaps(
     // 11 --
     //
     // All items must be Some on the same side.
-    let mut one_side_lines: Vec<(Option<LineNumber>, Option<LineNumber>)> = vec![];
+    let mut unpaired_lines: Vec<(Option<LineNumber>, Option<LineNumber>)> = vec![];
 
-    for (lhs_line, rhs_line) in items.into_iter() {
+    for (lhs_line, rhs_line) in items {
         match (lhs_line, rhs_line) {
             (Some(lhs_line), None) => {
-                match one_side_lines.first() {
+                match unpaired_lines.first() {
                     Some((None, Some(rhs_line))) => {
                         // We've found a line that can be compacted.
-                        res.push((Some(lhs_line), Some(*rhs_line)));
-                        one_side_lines.remove(0);
+                        res.push((Some(*lhs_line), Some(*rhs_line)));
+                        unpaired_lines.remove(0);
                     }
                     _ => {
-                        // We can't compact this item, so start new chunk.
-                        res.extend(one_side_lines);
-                        one_side_lines = vec![(Some(lhs_line), None)];
+                        unpaired_lines.push((Some(*lhs_line), None));
                     }
                 }
             }
             (None, Some(rhs_line)) => {
-                match one_side_lines.first() {
+                match unpaired_lines.first() {
                     Some((Some(lhs_line), None)) => {
                         // We've found a line that can be compacted.
-                        res.push((Some(*lhs_line), Some(rhs_line)));
-                        one_side_lines.remove(0);
+                        res.push((Some(*lhs_line), Some(*rhs_line)));
+                        unpaired_lines.remove(0);
                     }
                     _ => {
-                        // We can't compact this item, so start new chunk of one-side lines.
-                        res.extend(one_side_lines);
-                        one_side_lines = vec![(None, Some(rhs_line))];
+                        unpaired_lines.push((None, Some(*rhs_line)));
                     }
                 }
             }
             _ => {
-                res.extend(one_side_lines);
-                one_side_lines = vec![];
-                res.push((lhs_line, rhs_line));
+                res.extend(unpaired_lines);
+                unpaired_lines = vec![];
+                res.push((*lhs_line, *rhs_line));
             }
         }
     }
 
-    res.extend(one_side_lines);
+    res.extend(unpaired_lines);
     res
 }
 
@@ -709,7 +705,7 @@ mod tests {
             },
         };
         let matched_mp = MatchedPos {
-            kind: MatchKind::Unchanged {
+            kind: MatchKind::UnchangedToken {
                 highlight: TokenKind::Delimiter,
                 self_pos: vec![SingleLineSpan {
                     line: 1.into(),
@@ -755,7 +751,7 @@ mod tests {
                 },
             },
             MatchedPos {
-                kind: MatchKind::Unchanged {
+                kind: MatchKind::UnchangedToken {
                     highlight: TokenKind::Delimiter,
                     self_pos: vec![matched_pos],
                     opposite_pos: vec![matched_pos],
@@ -776,7 +772,7 @@ mod tests {
                 },
             },
             MatchedPos {
-                kind: MatchKind::Unchanged {
+                kind: MatchKind::UnchangedToken {
                     highlight: TokenKind::Delimiter,
                     self_pos: vec![matched_pos],
                     opposite_pos: vec![matched_pos],
@@ -789,4 +785,37 @@ mod tests {
         assert_eq!(hunks.len(), 1);
         assert_eq!(hunks[0].lines, vec![(Some(0.into()), Some(0.into()))]);
     }
+
+    #[test]
+    fn test_compact_gaps() {
+        let res = compact_gaps(&[
+            (Some(0.into()), None),
+            (None, Some(0.into())),
+            (Some(1.into()), Some(1.into())),
+        ]);
+        assert_eq!(
+            res,
+            vec![
+                (Some(0.into()), Some(0.into())),
+                (Some(1.into()), Some(1.into())),
+            ]
+        )
+    }
+
+    #[test]
+    fn test_compact_gaps_with_larger_gap() {
+        let res = compact_gaps(&[
+            (Some(0.into()), None),
+            (Some(1.into()), None),
+            (None, Some(0.into())),
+            (None, Some(1.into())),
+        ]);
+        assert_eq!(
+            res,
+            vec![
+                (Some(0.into()), Some(0.into())),
+                (Some(1.into()), Some(1.into())),
+            ]
+        )
+    }
 }
