@@ -33,11 +33,31 @@ fn format_line_num_padded(line_num: LineNumber, column_width: usize) -> String {
     )
 }
 
-fn format_missing_line_num(prev_num: LineNumber, column_width: usize) -> String {
+fn format_missing_line_num(
+    prev_num: LineNumber,
+    source_dims: &SourceDimensions,
+    is_lhs: bool,
+) -> String {
+    let column_width = if is_lhs {
+        source_dims.lhs_line_nums_width
+    } else {
+        source_dims.rhs_line_nums_width
+    };
+
+    let after_end = if is_lhs {
+        prev_num >= source_dims.lhs_max_line
+    } else {
+        prev_num >= source_dims.rhs_max_line
+    };
+
+    if after_end && !is_lhs {
+        return "".into();
+    }
+
     let num_digits = format!("{}", prev_num.one_indexed()).len();
     format!(
         "{:>width$} ",
-        ".".repeat(num_digits),
+        (if after_end { " " } else { "." }).repeat(num_digits),
         width = column_width - 1
     )
     .dimmed()
@@ -81,7 +101,7 @@ fn display_single_column(
 fn display_line_nums(
     lhs_line_num: Option<LineNumber>,
     rhs_line_num: Option<LineNumber>,
-    widths: &Widths,
+    source_dims: &SourceDimensions,
     background: BackgroundColor,
     lhs_has_novel: bool,
     rhs_has_novel: bool,
@@ -90,7 +110,7 @@ fn display_line_nums(
 ) -> (String, String) {
     let display_lhs_line_num: String = match lhs_line_num {
         Some(line_num) => {
-            let s = format_line_num_padded(line_num, widths.lhs_line_nums);
+            let s = format_line_num_padded(line_num, source_dims.lhs_line_nums_width);
             if lhs_has_novel {
                 // TODO: factor out applying colours to line numbers.
                 match background {
@@ -104,12 +124,13 @@ fn display_line_nums(
         }
         None => format_missing_line_num(
             prev_lhs_line_num.unwrap_or_else(|| 1.into()),
-            widths.lhs_line_nums,
+            source_dims,
+            true,
         ),
     };
     let display_rhs_line_num: String = match rhs_line_num {
         Some(line_num) => {
-            let s = format_line_num_padded(line_num, widths.rhs_line_nums);
+            let s = format_line_num_padded(line_num, source_dims.rhs_line_nums_width);
             if rhs_has_novel {
                 match background {
                     BackgroundColor::Dark => s.bright_green(),
@@ -122,7 +143,8 @@ fn display_line_nums(
         }
         None => format_missing_line_num(
             prev_rhs_line_num.unwrap_or_else(|| 1.into()),
-            widths.rhs_line_nums,
+            source_dims,
+            false,
         ),
     };
 
@@ -130,14 +152,16 @@ fn display_line_nums(
 }
 
 // Sizes used when displaying a hunk.
-struct Widths {
-    lhs_content: usize,
-    rhs_content: usize,
-    lhs_line_nums: usize,
-    rhs_line_nums: usize,
+struct SourceDimensions {
+    lhs_content_width: usize,
+    rhs_content_width: usize,
+    lhs_line_nums_width: usize,
+    rhs_line_nums_width: usize,
+    lhs_max_line: LineNumber,
+    rhs_max_line: LineNumber,
 }
 
-impl Widths {
+impl SourceDimensions {
     fn new(
         terminal_width: usize,
         line_nums: &[(Option<LineNumber>, Option<LineNumber>)],
@@ -169,10 +193,12 @@ impl Widths {
             terminal_width - lhs_total_width - SPACER.len() - rhs_line_nums_width;
 
         Self {
-            lhs_content: lhs_content_width,
-            rhs_content: rhs_content_width,
-            lhs_line_nums: lhs_line_nums_width,
-            rhs_line_nums: rhs_line_nums_width,
+            lhs_content_width,
+            rhs_content_width,
+            lhs_line_nums_width,
+            rhs_line_nums_width,
+            lhs_max_line,
+            rhs_max_line,
         }
     }
 }
@@ -249,7 +275,7 @@ fn highlight_as_novel(
     false
 }
 
-pub fn display_hunks(
+pub fn print(
     hunks: &[Hunk],
     display_width: usize,
     background: BackgroundColor,
@@ -259,15 +285,21 @@ pub fn display_hunks(
     rhs_src: &str,
     lhs_mps: &[MatchedPos],
     rhs_mps: &[MatchedPos],
-) -> String {
+) {
     let lhs_colored_src = apply_colors(lhs_src, true, background, lhs_mps);
     let rhs_colored_src = apply_colors(rhs_src, false, background, rhs_mps);
 
     if lhs_src.is_empty() {
-        return display_single_column(display_path, lang_name, &rhs_colored_src, false, background);
+        println!(
+            "{}",
+            display_single_column(display_path, lang_name, &rhs_colored_src, false, background)
+        );
     }
     if rhs_src.is_empty() {
-        return display_single_column(display_path, lang_name, &lhs_colored_src, true, background);
+        println!(
+            "{}",
+            display_single_column(display_path, lang_name, &lhs_colored_src, true, background)
+        );
     }
 
     // TODO: this is largely duplicating the `apply_colors` logic.
@@ -284,23 +316,19 @@ pub fn display_hunks(
 
     let matched_lines = all_matched_lines_filled(lhs_mps, rhs_mps);
 
-    let mut out_lines: Vec<String> = vec![];
-
     for (i, hunk) in hunks.iter().enumerate() {
-        out_lines.push(style::header(
-            display_path,
-            i + 1,
-            hunks.len(),
-            lang_name,
-            background,
-        ));
+        println!(
+            "{}",
+            style::header(display_path, i + 1, hunks.len(), lang_name, background)
+        );
 
         let aligned_lines = matched_lines_for_hunk(&matched_lines, hunk);
         let no_lhs_changes = hunk.novel_lhs.is_empty();
         let no_rhs_changes = hunk.novel_rhs.is_empty();
         let same_lines = aligned_lines.iter().all(|(l, r)| l == r);
 
-        let widths = Widths::new(display_width, &aligned_lines, &lhs_lines, &rhs_lines);
+        let source_dims =
+            SourceDimensions::new(display_width, &aligned_lines, &lhs_lines, &rhs_lines);
         for (lhs_line_num, rhs_line_num) in aligned_lines {
             let lhs_line_novel = highlight_as_novel(
                 lhs_line_num,
@@ -318,7 +346,7 @@ pub fn display_hunks(
             let (display_lhs_line_num, display_rhs_line_num) = display_line_nums(
                 lhs_line_num,
                 rhs_line_num,
-                &widths,
+                &source_dims,
                 background,
                 lhs_line_novel,
                 rhs_line_novel,
@@ -331,19 +359,19 @@ pub fn display_hunks(
                     Some(rhs_line_num) => {
                         let rhs_line = &rhs_colored_lines[rhs_line_num.0];
                         if same_lines {
-                            out_lines.push(format!("{}{}", display_rhs_line_num, rhs_line));
+                            println!("{}{}", display_rhs_line_num, rhs_line);
                         } else {
-                            out_lines.push(format!(
+                            println!(
                                 "{}{}{}",
                                 display_lhs_line_num, display_rhs_line_num, rhs_line
-                            ));
+                            );
                         }
                     }
                     None => {
                         // We didn't have any changed RHS lines in the
                         // hunk, but we had some contextual lines that
                         // only occurred on the LHS (e.g. extra newlines).
-                        out_lines.push(format!("{}{}", display_rhs_line_num, display_rhs_line_num));
+                        println!("{}{}", display_rhs_line_num, display_rhs_line_num);
                     }
                 }
             } else if no_rhs_changes {
@@ -351,31 +379,31 @@ pub fn display_hunks(
                     Some(lhs_line_num) => {
                         let lhs_line = &lhs_colored_lines[lhs_line_num.0];
                         if same_lines {
-                            out_lines.push(format!("{}{}", display_lhs_line_num, lhs_line));
+                            println!("{}{}", display_lhs_line_num, lhs_line);
                         } else {
-                            out_lines.push(format!(
+                            println!(
                                 "{}{}{}",
                                 display_lhs_line_num, display_rhs_line_num, lhs_line
-                            ));
+                            );
                         }
                     }
                     None => {
-                        out_lines.push(format!("{}{}", display_lhs_line_num, display_rhs_line_num));
+                        println!("{}{}", display_lhs_line_num, display_rhs_line_num);
                     }
                 }
             } else {
                 let lhs_line = match lhs_line_num {
                     Some(lhs_line_num) => split_and_apply(
                         lhs_lines[lhs_line_num.0],
-                        widths.lhs_content,
+                        source_dims.lhs_content_width,
                         lhs_highlights.get(&lhs_line_num).unwrap_or(&vec![]),
                     ),
-                    None => vec![" ".repeat(widths.lhs_content)],
+                    None => vec![" ".repeat(source_dims.lhs_content_width)],
                 };
                 let rhs_line = match rhs_line_num {
                     Some(rhs_line_num) => split_and_apply(
                         rhs_lines[rhs_line_num.0],
-                        widths.rhs_content,
+                        source_dims.rhs_content_width,
                         rhs_highlights.get(&rhs_line_num).unwrap_or(&vec![]),
                     ),
                     None => vec!["".into()],
@@ -385,7 +413,8 @@ pub fn display_hunks(
                     .into_iter()
                     .enumerate()
                 {
-                    let lhs_line = lhs_line.unwrap_or_else(|| " ".repeat(widths.lhs_content));
+                    let lhs_line =
+                        lhs_line.unwrap_or_else(|| " ".repeat(source_dims.lhs_content_width));
                     let rhs_line = rhs_line.unwrap_or_else(|| "".into());
                     let lhs_num: String = if i == 0 {
                         display_lhs_line_num.clone()
@@ -393,7 +422,8 @@ pub fn display_hunks(
                         let mut s = format_missing_line_num(
                             lhs_line_num
                                 .unwrap_or_else(|| prev_lhs_line_num.unwrap_or_else(|| 10.into())),
-                            widths.lhs_line_nums,
+                            &source_dims,
+                            true,
                         );
                         if let Some(line_num) = lhs_line_num {
                             if lhs_lines_with_novel.contains(&line_num) {
@@ -412,7 +442,8 @@ pub fn display_hunks(
                         let mut s = format_missing_line_num(
                             rhs_line_num
                                 .unwrap_or_else(|| prev_rhs_line_num.unwrap_or_else(|| 10.into())),
-                            widths.rhs_line_nums,
+                            &source_dims,
+                            false,
                         );
                         if let Some(line_num) = rhs_line_num {
                             if rhs_lines_with_novel.contains(&line_num) {
@@ -426,10 +457,7 @@ pub fn display_hunks(
                         s
                     };
 
-                    out_lines.push(format!(
-                        "{}{}{}{}{}",
-                        lhs_num, lhs_line, SPACER, rhs_num, rhs_line
-                    ));
+                    println!("{}{}{}{}{}", lhs_num, lhs_line, SPACER, rhs_num, rhs_line);
                 }
             }
 
@@ -440,10 +468,8 @@ pub fn display_hunks(
                 prev_rhs_line_num = rhs_line_num;
             }
         }
-        out_lines.push("".into());
+        println!();
     }
-
-    out_lines.join("\n")
 }
 
 #[cfg(test)]
@@ -456,15 +482,51 @@ mod tests {
     #[test]
     fn test_width_calculations() {
         let line_nums = [(Some(1.into()), Some(10.into()))];
-        let widths = Widths::new(
+        let source_dims = SourceDimensions::new(
             80,
             &line_nums,
             &split_on_newlines("foo\nbar\n"),
             &split_on_newlines("x\nx\nx\nx\nx\nx\nx\nx\nx\nx\nx\n"),
         );
 
-        assert_eq!(widths.lhs_line_nums, 2);
-        assert_eq!(widths.rhs_line_nums, 3);
+        assert_eq!(source_dims.lhs_line_nums_width, 2);
+        assert_eq!(source_dims.rhs_line_nums_width, 3);
+    }
+
+    #[test]
+    fn test_format_missing_line_num() {
+        let source_dims = SourceDimensions::new(
+            80,
+            &[
+                (Some(0.into()), Some(0.into())),
+                (Some(1.into()), Some(1.into())),
+            ],
+            &split_on_newlines("foo\nbar\n"),
+            &split_on_newlines("fox\nbax\n"),
+        );
+
+        assert_eq!(
+            format_missing_line_num(0.into(), &source_dims, true),
+            ". ".dimmed().to_string()
+        );
+    }
+
+    #[test]
+    fn test_format_missing_line_num_at_end() {
+        let source_dims = SourceDimensions::new(
+            80,
+            &[
+                (Some(0.into()), Some(0.into())),
+                (Some(1.into()), Some(1.into())),
+            ],
+            &split_on_newlines("foo\nbar\n"),
+            &split_on_newlines("fox\nbax\n"),
+        );
+
+        assert_eq!(
+            format_missing_line_num(1.into(), &source_dims, true),
+            "  ".dimmed().to_string()
+        );
     }
 
     #[test]
@@ -536,7 +598,6 @@ mod tests {
         let mut novel_rhs = HashSet::new();
         novel_rhs.insert(0.into());
 
-
         let hunks = [Hunk {
             novel_lhs,
             novel_rhs,
@@ -544,7 +605,7 @@ mod tests {
         }];
 
         // Simple smoke test.
-        display_hunks(
+        print(
             &hunks,
             80,
             BackgroundColor::Dark,
