@@ -531,7 +531,7 @@ pub enum TokenKind {
 /// A matched token (an atom, a delimiter, or a comment word).
 #[derive(PartialEq, Eq, Debug, Clone)]
 pub enum MatchKind {
-    Unchanged {
+    UnchangedToken {
         highlight: TokenKind,
         self_pos: Vec<SingleLineSpan>,
         opposite_pos: Vec<SingleLineSpan>,
@@ -539,27 +539,30 @@ pub enum MatchKind {
     Novel {
         highlight: TokenKind,
     },
-    UnchangedCommentPart {
+    NovelLinePart {
+        highlight: TokenKind,
         self_pos: SingleLineSpan,
         opposite_pos: Vec<SingleLineSpan>,
     },
-    ChangedCommentPart {},
+    NovelWord {
+        highlight: TokenKind,
+    },
 }
 
 impl MatchKind {
     pub fn first_opposite_span(&self) -> Option<SingleLineSpan> {
         match self {
-            MatchKind::Unchanged { opposite_pos, .. } => opposite_pos.first().copied(),
-            MatchKind::UnchangedCommentPart { opposite_pos, .. } => opposite_pos.first().copied(),
+            MatchKind::UnchangedToken { opposite_pos, .. } => opposite_pos.first().copied(),
+            MatchKind::NovelLinePart { opposite_pos, .. } => opposite_pos.first().copied(),
             MatchKind::Novel { .. } => None,
-            MatchKind::ChangedCommentPart {} => None,
+            MatchKind::NovelWord { .. } => None,
         }
     }
 
     pub fn is_change(&self) -> bool {
         matches!(
             self,
-            MatchKind::Novel { .. } | MatchKind::ChangedCommentPart {}
+            MatchKind::Novel { .. } | MatchKind::NovelWord { .. } | MatchKind::NovelLinePart { .. }
         )
     }
 }
@@ -602,7 +605,9 @@ fn split_comment_words(
             diff::Result::Left(word) => {
                 // This word is novel to this side.
                 res.push(MatchedPos {
-                    kind: MatchKind::ChangedCommentPart {},
+                    kind: MatchKind::NovelWord {
+                        highlight: TokenKind::Atom(AtomKind::Comment),
+                    },
                     pos: content_newlines.from_offsets_relative_to(
                         pos,
                         offset,
@@ -622,7 +627,8 @@ fn split_comment_words(
                 );
 
                 res.push(MatchedPos {
-                    kind: MatchKind::UnchangedCommentPart {
+                    kind: MatchKind::NovelLinePart {
+                        highlight: TokenKind::Atom(AtomKind::Comment),
                         self_pos: word_pos,
                         opposite_pos: opposite_word_pos,
                     },
@@ -685,7 +691,7 @@ impl MatchedPos {
                     Atom { position, .. } => position.clone(),
                 };
 
-                MatchKind::Unchanged {
+                MatchKind::UnchangedToken {
                     highlight,
                     self_pos: pos.to_vec(),
                     opposite_pos,
@@ -716,25 +722,13 @@ impl MatchedPos {
 }
 
 /// Walk `nodes` and return a vec of all the changed positions.
-pub fn change_positions<'a>(
-    src: &str,
-    opposite_src: &str,
-    nodes: &[&'a Syntax<'a>],
-) -> Vec<MatchedPos> {
-    let nl_pos = NewlinePositions::from(src);
-    let opposite_nl_pos = NewlinePositions::from(opposite_src);
-
+pub fn change_positions<'a>(nodes: &[&'a Syntax<'a>]) -> Vec<MatchedPos> {
     let mut positions = Vec::new();
-    change_positions_(&nl_pos, &opposite_nl_pos, nodes, &mut positions);
+    change_positions_(nodes, &mut positions);
     positions
 }
 
-fn change_positions_<'a>(
-    nl_pos: &NewlinePositions,
-    opposite_nl_pos: &NewlinePositions,
-    nodes: &[&'a Syntax<'a>],
-    positions: &mut Vec<MatchedPos>,
-) {
+fn change_positions_<'a>(nodes: &[&'a Syntax<'a>], positions: &mut Vec<MatchedPos>) {
     for node in nodes {
         let change = node
             .change()
@@ -754,7 +748,7 @@ fn change_positions_<'a>(
                     false,
                 ));
 
-                change_positions_(nl_pos, opposite_nl_pos, children, positions);
+                change_positions_(children, positions);
 
                 positions.extend(MatchedPos::new(
                     change,
@@ -933,7 +927,9 @@ mod tests {
         assert_eq!(
             res,
             vec![MatchedPos {
-                kind: MatchKind::ChangedCommentPart {},
+                kind: MatchKind::NovelWord {
+                    highlight: TokenKind::Atom(AtomKind::Comment),
+                },
                 pos: SingleLineSpan {
                     line: 0.into(),
                     start_col: 0,
