@@ -68,9 +68,10 @@ extern "C" {
 }
 
 // TODO: begin/end and object/end.
-const OCAML_ATOM_NODES: [&str; 5] = [
+const OCAML_ATOM_NODES: [&str; 6] = [
     "character",
     "string",
+    "quoted_string",
     "tag",
     "type_variable",
     "attribute_id",
@@ -99,7 +100,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_c() };
             TreeSitterConfig {
                 name: "C",
-                language: unsafe { tree_sitter_c() },
+                language,
                 atom_nodes: (vec!["string_literal", "char_literal"])
                     .into_iter()
                     .collect(),
@@ -115,7 +116,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_cpp() };
             TreeSitterConfig {
                 name: "C++",
-                language: unsafe { tree_sitter_cpp() },
+                language,
                 // The C++ grammar extends the C grammar, so the node
                 // names are generally the same.
                 atom_nodes: (vec!["string_literal", "char_literal"])
@@ -136,7 +137,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_clojure() };
             TreeSitterConfig {
                 name: "Clojure",
-                language: unsafe { tree_sitter_clojure() },
+                language,
                 atom_nodes: (vec![]).into_iter().collect(),
                 delimiter_tokens: (vec![("{", "}"), ("(", ")"), ("[", "]")])
                     .into_iter()
@@ -148,7 +149,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_commonlisp() };
             TreeSitterConfig {
                 name: "Common Lisp",
-                language: unsafe { tree_sitter_commonlisp() },
+                language,
                 atom_nodes: (vec!["str_lit", "char_lit"]).into_iter().collect(),
                 delimiter_tokens: (vec![("(", ")")]),
                 highlight_query: ts::Query::new(language, "").unwrap(),
@@ -158,7 +159,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_c_sharp() };
             TreeSitterConfig {
                 name: "C#",
-                language: unsafe { tree_sitter_c_sharp() },
+                language,
                 atom_nodes: (vec![
                     "string_literal",
                     "verbatim_string_literal",
@@ -178,7 +179,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_css() };
             TreeSitterConfig {
                 name: "CSS",
-                language: unsafe { tree_sitter_css() },
+                language,
                 atom_nodes: (vec!["integer_value", "float_value"]).into_iter().collect(),
                 delimiter_tokens: (vec![("{", "}"), ("(", ")")]),
                 highlight_query: ts::Query::new(
@@ -192,7 +193,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_elisp() };
             TreeSitterConfig {
                 name: "Emacs Lisp",
-                language: unsafe { tree_sitter_elisp() },
+                language,
                 atom_nodes: (vec![]).into_iter().collect(),
                 delimiter_tokens: (vec![("{", "}"), ("(", ")"), ("[", "]")])
                     .into_iter()
@@ -208,7 +209,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_elixir() };
             TreeSitterConfig {
                 name: "Elixir",
-                language: unsafe { tree_sitter_elixir() },
+                language,
                 atom_nodes: (vec!["string", "heredoc"]).into_iter().collect(),
                 delimiter_tokens: (vec![("(", ")"), ("{", "}"), ("do", "end")])
                     .into_iter()
@@ -224,7 +225,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_go() };
             TreeSitterConfig {
                 name: "Go",
-                language: unsafe { tree_sitter_go() },
+                language,
                 atom_nodes: (vec!["interpreted_string_literal", "raw_string_literal"])
                     .into_iter()
                     .collect(),
@@ -242,7 +243,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_haskell() };
             TreeSitterConfig {
                 name: "Haskell",
-                language: unsafe { tree_sitter_haskell() },
+                language,
                 atom_nodes: (vec![]).into_iter().collect(),
                 delimiter_tokens: (vec![("[", "]"), ("(", ")")]),
                 highlight_query: ts::Query::new(
@@ -256,7 +257,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_java() };
             TreeSitterConfig {
                 name: "Java",
-                language: unsafe { tree_sitter_java() },
+                language,
                 atom_nodes: (vec![]).into_iter().collect(),
                 delimiter_tokens: (vec![("(", ")"), ("{", "}")]),
                 highlight_query: ts::Query::new(
@@ -270,7 +271,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_javascript() };
             TreeSitterConfig {
                 name: "JavaScript",
-                language: unsafe { tree_sitter_javascript() },
+                language,
                 atom_nodes: (vec!["string", "template_string", "regex"])
                     .into_iter()
                     .collect(),
@@ -294,7 +295,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_json() };
             TreeSitterConfig {
                 name: "JSON",
-                language: unsafe { tree_sitter_json() },
+                language,
                 atom_nodes: (vec!["string"]).into_iter().collect(),
                 delimiter_tokens: (vec![("{", "}"), ("[", "]")]),
                 highlight_query: ts::Query::new(
@@ -308,7 +309,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_ocaml() };
             TreeSitterConfig {
                 name: "OCaml",
-                language: unsafe { tree_sitter_ocaml() },
+                language,
                 atom_nodes: OCAML_ATOM_NODES.iter().cloned().collect(),
                 delimiter_tokens: (vec![("(", ")"), ("[", "]"), ("{", "}")]),
                 highlight_query: ts::Query::new(
@@ -322,7 +323,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_ocaml_interface() };
             TreeSitterConfig {
                 name: "OCaml Interface",
-                language: unsafe { tree_sitter_ocaml_interface() },
+                language,
                 atom_nodes: OCAML_ATOM_NODES.iter().cloned().collect(),
                 delimiter_tokens: (vec![("(", ")"), ("[", "]"), ("{", "}")]),
                 highlight_query: ts::Query::new(
@@ -336,7 +337,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_python() };
             TreeSitterConfig {
                 name: "Python",
-                language: unsafe { tree_sitter_python() },
+                language,
                 atom_nodes: (vec!["string"]).into_iter().collect(),
                 delimiter_tokens: (vec![("(", ")"), ("[", "]"), ("{", "}")]),
                 highlight_query: ts::Query::new(
@@ -350,7 +351,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_ruby() };
             TreeSitterConfig {
                 name: "Ruby",
-                language: unsafe { tree_sitter_ruby() },
+                language,
                 atom_nodes: (vec!["string", "heredoc_body", "regex"])
                     .into_iter()
                     .collect(),
@@ -374,7 +375,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_rust() };
             TreeSitterConfig {
                 name: "Rust",
-                language: unsafe { tree_sitter_rust() },
+                language,
                 atom_nodes: (vec!["char_literal", "string_literal"])
                     .into_iter()
                     .collect(),
@@ -390,7 +391,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_scala() };
             TreeSitterConfig {
                 name: "Scala",
-                language: unsafe { tree_sitter_scala() },
+                language,
                 atom_nodes: (vec!["string", "template_string"]).into_iter().collect(),
                 delimiter_tokens: (vec![("{", "}"), ("(", ")"), ("[", "]")]),
                 highlight_query: ts::Query::new(language, "").unwrap(),
@@ -400,14 +401,17 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_typescript() };
             TreeSitterConfig {
                 name: "TypeScript",
-                language: unsafe { tree_sitter_typescript() },
+                language,
                 atom_nodes: (vec!["string", "template_string", "regex"])
                     .into_iter()
                     .collect(),
                 delimiter_tokens: (vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")]),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../vendor/highlights/typescript.scm"),
+                    concat!(
+                        include_str!("../vendor/highlights/javascript.scm"),
+                        include_str!("../vendor/highlights/typescript.scm"),
+                    ),
                 )
                 .unwrap(),
             }
@@ -416,12 +420,15 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             let language = unsafe { tree_sitter_tsx() };
             TreeSitterConfig {
                 name: "TypeScript TSX",
-                language: unsafe { tree_sitter_tsx() },
+                language,
                 atom_nodes: (vec!["string", "template_string"]).into_iter().collect(),
                 delimiter_tokens: (vec![("{", "}"), ("(", ")"), ("[", "]"), ("<", ">")]),
                 highlight_query: ts::Query::new(
                     language,
-                    include_str!("../vendor/highlights/typescript.scm"),
+                    concat!(
+                        include_str!("../vendor/highlights/javascript.scm"),
+                        include_str!("../vendor/highlights/typescript.scm"),
+                    ),
                 )
                 .unwrap(),
             }
@@ -451,6 +458,12 @@ pub fn parse_to_tree(
     if let Some(idx) = config.highlight_query.capture_index_for_name("constant") {
         keyword_ish_capture_ids.push(idx);
     }
+    if let Some(idx) = config
+        .highlight_query
+        .capture_index_for_name("constant.builtin")
+    {
+        keyword_ish_capture_ids.push(idx);
+    }
 
     let mut string_capture_ids = vec![];
     if let Some(idx) = config.highlight_query.capture_index_for_name("string") {
@@ -802,7 +815,7 @@ fn atom_from_cursor<'a>(
         content = content.trim();
     }
 
-    let highlight = if node.is_extra() {
+    let highlight = if node.is_extra() || node.kind() == "comment" {
         AtomKind::Comment
     } else if highlights.keyword_ids.contains(&node.id()) {
         AtomKind::Keyword
